flutter_redirectly library
Classes
- AppInfo
- FlutterRedirectly
- Abstract interface for Flutter Redirectly plugin
- RedirectlyAppInstallLink
- Link details in app install response
- RedirectlyAppInstallRequest
- App install request model for Redirectly
- RedirectlyAppInstallResponse
- App install response model for Redirectly
- RedirectlyConfig
- Configuration for initializing Flutter Redirectly
- RedirectlyLink
- Represents a permanent Redirectly link
- RedirectlyLinkClick
- Represents a click on a Redirectly link
- RedirectlyLinkResolution
- Represents the resolution of a Redirectly link (permanent or temporary)
- RedirectlyTempLink
- Represents a temporary Redirectly link with expiration
Enums
- RedirectlyErrorType
- Types of errors that can occur
Extensions
- RedirectlyLinkClickX on RedirectlyLinkClick
- Extension methods for RedirectlyLinkClick
Typedefs
-
InstallReferrerProvider
= Future<
String?> Function() -
Signature of a callback that returns the raw Google Play Install
Referrer string, for example via the
android_play_install_referrerpackage. Return null when the referrer is unavailable.
Exceptions / Errors
- RedirectlyError
- Represents errors that can occur in Flutter Redirectly operations