InstallReferrerProvider typedef

InstallReferrerProvider = Future<String?> Function()

Signature of a callback that returns the raw Google Play Install Referrer string, for example via the android_play_install_referrer package. Return null when the referrer is unavailable.

Implementation

typedef InstallReferrerProvider = Future<String?> Function();