RedirectlyAppInstallLink class

Link details in app install response

Constructors

RedirectlyAppInstallLink({required String slug, required String? target, required String url, required DateTime createdAt, Map<String, dynamic>? metadata})
const
RedirectlyAppInstallLink.fromJson(Map<String, dynamic> json)
Create from JSON
factory

Properties

createdAt DateTime
Creation timestamp
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
Link metadata
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String
Link slug
final
target String?
Target URL
final
url String
Full clickable URL
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited